package com.jsowell.pile.mapper;

import com.jsowell.pile.domain.PileMerchantInfo;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 充电桩运营商信息Mapper接口
 *
 * @author jsowell
 * @date 2022-08-27
 */
@Repository
public interface PileMerchantInfoMapper {
	/**
	 * 查询充电桩运营商信息
	 *
	 * @param id 充电桩运营商信息主键
	 * @return 充电桩运营商信息
	 */
	public PileMerchantInfo selectPileMerchantInfoById(Long id);

	/**
	 * 通过appid查询充电桩运营商信息
	 * @param appId
	 * @return
	 */
	PileMerchantInfo selectPileMerchantInfoByAppId(String appId);

	/**
	 * 查询充电桩运营商信息列表
	 *
	 * @param pileMerchantInfo 充电桩运营商信息
	 * @return 充电桩运营商信息集合
	 */
	public List<PileMerchantInfo> selectPileMerchantInfoList(PileMerchantInfo pileMerchantInfo);

	/**
	 * 新增充电桩运营商信息
	 *
	 * @param pileMerchantInfo 充电桩运营商信息
	 * @return 结果
	 */
	public int insertPileMerchantInfo(PileMerchantInfo pileMerchantInfo);

	/**
	 * 修改充电桩运营商信息
	 *
	 * @param pileMerchantInfo 充电桩运营商信息
	 * @return 结果
	 */
	public int updatePileMerchantInfo(PileMerchantInfo pileMerchantInfo);

	/**
	 * 删除充电桩运营商信息
	 *
	 * @param id 充电桩运营商信息主键
	 * @return 结果
	 */
	public int deletePileMerchantInfoById(Long id);

	/**
	 * 批量删除充电桩运营商信息
	 *
	 * @param ids 需要删除的数据主键集合
	 * @return 结果
	 */
	public int deletePileMerchantInfoByIds(Long[] ids);

	List<String> queryByMerchantDeptIds(@Param("merchantDeptIds") List<String> merchantDeptIds);
}
